@@ -1,7 +1,7 @@
 /*
- * Copyright (C) 2009-2013 B.A.T.M.A.N. contributors:
+ * Copyright (C) 2009-2014 B.A.T.M.A.N. contributors:
  *
- * Marek Lindner <lindner_marek@yahoo.de>
+ * Marek Lindner <mareklindner@neomailbox.ch>
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of version 2 of the GNU General Public
@@ -21,10 +21,10 @@
 
 
 
-#ifndef _BAT_HOSTS_H
-#define _BAT_HOSTS_H 1
+#ifndef _BATCTL_BAT_HOSTS_H
+#define _BATCTL_BAT_HOSTS_H
 
-#include <netinet/ether.h>
+#include <net/ethernet.h>
 
 #define HOST_NAME_MAX_LEN 50
 #define CONF_DIR_LEN 256
