@@ -1,7 +1,7 @@
 /*
- * Copyright (C) 2009-2013 B.A.T.M.A.N. contributors:
+ * Copyright (C) 2009-2014 B.A.T.M.A.N. contributors:
  *
- * Marek Lindner <lindner_marek@yahoo.de>
+ * Marek Lindner <mareklindner@neomailbox.ch>
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of version 2 of the GNU General Public
@@ -19,6 +19,9 @@
  *
  */
 
+#ifndef _BATCTL_BISECT_IV_H
+#define _BATCTL_BISECT_IV_H
+
 #include "list-batman.h"
 
 #define NAME_LEN 18
@@ -95,3 +98,5 @@ struct seqno_trace {
 	char print;
 	struct seqno_trace_neigh seqno_trace_neigh;
 };
+
+#endif
