@@ -1,7 +1,7 @@
 /*
- * Copyright (C) 2007-2013 B.A.T.M.A.N. contributors:
+ * Copyright (C) 2007-2014 B.A.T.M.A.N. contributors:
  *
- * Andreas Langer <an.langer@gmx.de>, Marek Lindner <lindner_marek@yahoo.de>
+ * Andreas Langer <an.langer@gmx.de>, Marek Lindner <mareklindner@neomailbox.ch>
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of version 2 of the GNU General Public
@@ -19,9 +19,14 @@
  *
  */
 
+#ifndef _BATCTL_TCPDUMP_H
+#define _BATCTL_TCPDUMP_H
 
 #include <netpacket/packet.h>
-#include <net/ethernet.h>
+#include <linux/if_ether.h>
+#include <net/if_arp.h>
+#include <sys/types.h>
+#include "main.h"
 #include "list-batman.h"
 
 #ifndef ARPHRD_IEEE80211_PRISM
@@ -36,9 +41,7 @@
 #define DUMP_TYPE_BATICMP 2
 #define DUMP_TYPE_BATUCAST 4
 #define DUMP_TYPE_BATBCAST 8
-#define DUMP_TYPE_BATVIS 16
 #define DUMP_TYPE_BATFRAG 32
-#define DUMP_TYPE_BATTT 64
 #define DUMP_TYPE_NONBAT 128
 
 #define IEEE80211_FCTL_FTYPE 0x0c00
@@ -107,3 +110,5 @@ struct prism_header {
 #define RADIOTAP_HEADER_LEN sizeof(struct radiotap_header)
 
 int tcpdump(int argc, char **argv);
+
+#endif
