@@ -1,7 +1,7 @@
 /*
- * Copyright (C) 2009-2013 B.A.T.M.A.N. contributors:
+ * Copyright (C) 2009-2014 B.A.T.M.A.N. contributors:
  *
- * Marek Lindner <lindner_marek@yahoo.de>
+ * Marek Lindner <mareklindner@neomailbox.ch>
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of version 2 of the GNU General Public
@@ -19,6 +19,9 @@
  *
  */
 
-
+#ifndef _BATCTL_TRACEROUTE_H
+#define _BATCTL_TRACEROUTE_H
 
 int traceroute(char *mesh_iface, int argc, char **argv);
+
+#endif
