@@ -1,7 +1,7 @@
 /*
- * Copyright (C) 2007-2013 B.A.T.M.A.N. contributors:
+ * Copyright (C) 2007-2014 B.A.T.M.A.N. contributors:
  *
- * Andreas Langer <an.langer@gmx.de>, Marek Lindner <lindner_marek@yahoo.de>
+ * Andreas Langer <an.langer@gmx.de>, Marek Lindner <mareklindner@neomailbox.ch>
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of version 2 of the GNU General Public
@@ -19,7 +19,6 @@
  *
  */
 
-#include <netinet/in.h>
 #include <stdio.h>
 #include <stdlib.h>
 
